@@ -447,7 +447,9 @@ class CloudWatchClient(BaseClient):
         MetricName: str = ...,
         Dimensions: Sequence[DimensionFilterTypeDef] = ...,
         NextToken: str = ...,
-        RecentlyActive: Literal["PT3H"] = ...
+        RecentlyActive: Literal["PT3H"] = ...,
+        IncludeLinkedAccounts: bool = ...,
+        OwningAccount: str = ...
     ) -> ListMetricsOutputTypeDef:
         """
         List the specified metrics.
