@@ -200,6 +200,8 @@ class ListMetricsPaginator(Paginator):
         MetricName: str = ...,
         Dimensions: Sequence[DimensionFilterTypeDef] = ...,
         RecentlyActive: Literal["PT3H"] = ...,
+        IncludeLinkedAccounts: bool = ...,
+        OwningAccount: str = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListMetricsOutputTypeDef]:
         """
