@@ -172,7 +172,9 @@ class ServiceResourceMetricsCollection(ResourceCollection):
         MetricName: str = ...,
         Dimensions: Sequence[DimensionFilterTypeDef] = ...,
         NextToken: str = ...,
-        RecentlyActive: Literal["PT3H"] = ...
+        RecentlyActive: Literal["PT3H"] = ...,
+        IncludeLinkedAccounts: bool = ...,
+        OwningAccount: str = ...
     ) -> "ServiceResourceMetricsCollection":
         """
         Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
