@@ -1071,6 +1071,8 @@ ListMetricsInputListMetricsPaginateTypeDef = TypedDict(
         "MetricName": str,
         "Dimensions": Sequence[DimensionFilterTypeDef],
         "RecentlyActive": Literal["PT3H"],
+        "IncludeLinkedAccounts": bool,
+        "OwningAccount": str,
         "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
@@ -1084,6 +1086,8 @@ ListMetricsInputRequestTypeDef = TypedDict(
         "Dimensions": Sequence[DimensionFilterTypeDef],
         "NextToken": str,
         "RecentlyActive": Literal["PT3H"],
+        "IncludeLinkedAccounts": bool,
+        "OwningAccount": str,
     },
     total=False,
 )
@@ -1257,6 +1261,7 @@ ListMetricsOutputTypeDef = TypedDict(
     {
         "Metrics": List[MetricTypeDef],
         "NextToken": str,
+        "OwningAccounts": List[str],
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
